# -*- coding: utf-8 -*-
from setuphelpers import *
import platform

uninstallkey = []

# Defining variables
bin_name_string = 'Lifesize_Setup_%s.msi'
conf_dir = makepath(programfiles32,'Lifesize Installer')
conf_file = 'settings.json'
conf_path = makepath(conf_dir,conf_file)


def install():
    # Initializing variables
    package_version = control.version.split('-')[0]
    bin_name = bin_name_string % package_version
    app_name = 'Lifesize Installer'

    # Uninstalling older versions
    for uninstall in installed_softwares(name=app_name):
        if Version(uninstall['version']) < Version(package_version):
            print('Older %s version found (%s)' % (app_name,uninstall['version']))
            print('Uninstalling: %s version %s' % (uninstall['name'],uninstall['version']))
            run(uninstall_cmd(uninstall['key']))

    # Installing the package
    print('Installing: %s' % bin_name)
    install_msi_if_needed(bin_name)

    # Adding configuration file
    print('Copying: %s to %s' % (conf_file,conf_path))
    filecopyto(conf_file,conf_path)


def update_package():
    print('Download/Update package content from upstream binary sources')

    # Initializing variables
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    url_dl = 'http://download.lifesizecloud.com/download?platform=msi'
    temp_bin = 'Lifesize_Setup.msi'

    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(temp_bin):
        remove_file(temp_bin)
    if not isfile(temp_bin):
        print('Downloading: ' + temp_bin)
        wget(url_dl,temp_bin,proxies=proxies)

        # Get version from file
        version = get_msi_properties(temp_bin)['ProductVersion']
        latest_bin = bin_name_string % version
        if isfile(latest_bin):
            remove_file(latest_bin)
        os.rename(temp_bin,latest_bin)

        # Changing version of the package
        control.version = '%s-%s'%(version,int(control.version.split('-')[-1])+1)
        control.save_control_to_wapt()
        print('Changing version to: %s in WAPT\\control' % control.version)




def get_proxies():
    if platform.python_version_tuple()[0] == '3':
        from urllib.request import getproxies
    else:
        from urllib import getproxies
    return getproxies()


def get_proxies_from_wapt_console():
    proxies = {}
    if platform.system() == 'Windows':
        waptconsole_ini_path = makepath(user_local_appdata(), 'waptconsole', 'waptconsole.ini')
    else:
        waptconsole_ini_path = makepath(user_home_directory(), '.config', 'waptconsole', 'waptconsole.ini')
    if isfile(waptconsole_ini_path):
        proxy_wapt = inifile_readstring(waptconsole_ini_path, 'global', 'http_proxy')
        if proxy_wapt:
            proxies = {'http': proxy_wapt, 'https': proxy_wapt}
    return proxies

